{% load i18n horizon %}
<div class="well">
<p>
    {% blocktrans %}This Cluster Template will be created for:{% endblocktrans %}
    <br >
    <b>{% blocktrans %}Plugin{% endblocktrans %}</b>: {{ plugin_name }}
    <br />
    <b>{% blocktrans %}Version{% endblocktrans %}</b>: {{ hadoop_version }}
    <br />
</p>
    {% if deprecated %}
    <div class="bs-component">
        <div class="alert alert-dismissable alert-warning">
          <button type="button" class="close" data-dismiss="alert">×</button>
          <h4><span class="ng-scope">{% blocktrans %}Warning!{% endblocktrans %}</span></h4>
          <p> {% blocktrans %} Version: <b>{{ hadoop_version }}</b>
              of plugin <b>{{ plugin_name }} </b>
              is now deprecated. {% endblocktrans %}
          </p>
        </div>
      </div>
    {% endif %}
<p>
    {% blocktrans %}The Cluster Template object should specify Node Group Templates that will be used to build a Cluster.
    You can add Node Groups using Node Group Templates on a &quot;Node Groups&quot; tab.{% endblocktrans %}
</p>
<p>
    {% blocktrans %}You may set <b>cluster</b> scoped configurations on corresponding tabs.{% endblocktrans %}
</p>
<p>
    {% blocktrans %}The Cluster Template object may specify a list of processes in anti-affinity group.
    That means these processes may not be launched more than once on a single host.{% endblocktrans %}
</p>
</div>
