{% load i18n horizon %}
<div class="well">
<p>
    {% blocktrans %}Select the domain name for internal and external hostname resolution.{% endblocktrans %}
</p>
<p>
    {% blocktrans %}Selected domain name should already exist in the Designate.
    You can check it in &quot;DNS&quot; tab on the left menu or by executing
    &quot;designate domain-list&quot;
    on the controller node.{% endblocktrans %}
</p>
</div>
